pub trait Capture: Send + Sync {
// Required method
fn request_snapshot<'life0, 'async_trait>(
&'life0 self,
request: SnapshotRequest,
) -> Pin<Box<dyn Future<Output = Result<SnapshotResult>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Defines the behavior required from a capture participant in the tools workflow.
Required Methods
Sourcefn request_snapshot<'life0, 'async_trait>(
&'life0 self,
request: SnapshotRequest,
) -> Pin<Box<dyn Future<Output = Result<SnapshotResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn request_snapshot<'life0, 'async_trait>(
&'life0 self,
request: SnapshotRequest,
) -> Pin<Box<dyn Future<Output = Result<SnapshotResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Resolves the request into source-grounded lookup evidence without editing provider records or contacting customers.